module Debate.Arguments.Inferences.EpidemiologyCausality exposing (..)

import Debate.Arguments.Types exposing (..)


argumentEpidemiologyCausality : Argument
argumentEpidemiologyCausality =
    { argumentTitle = "Argument for Nutritional Epidemiology"
    , propositionTitle = "Nutritional epidemiology generally provides good causal estimates."
    , propositionReductio = ""
    , propositionSummary = "It's just straightforwardly the case that nutritional epidemiology has outstanding translation rates with randomized controlled trials, or at least these is overwhelmingly consistent compatibility in the results. If randomized controlled trials are the standard against which other research methods are to be evaluated, it's not clear why nutritional epidemiology wouldn't be trustworthy in the aggregate."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~5Qx)),(Pe)|=(Qe)"
    
    , argumentCertainty = 8
    , argumentImage = "epidemiologycausality"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) consistently identifies associations that are later confirmed by randomized controlled trials"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) generally provides good causal estimates"
          }
        , { definiendum = "x"
          , definiens = "a research method"
          }
        , { definiendum = "e"
          , definiens = "nutritional epidemiology"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a research method consistently identifies associations that are later confirmed by randomized controlled trials, then the research method generally provides good causal estimates."
                  , notation = "∀x(Px→Qx)"
                  }
                , { premise = "Nutritional epidemiology consistently identifies associations that are later confirmed by randomized controlled trials."
                  , notation = "Pe"
                  }
                ]
          , conclusion = "Therefore, nutritional epidemiology generally provides good causal estimates."
          , conclusionNotation = "Qe"
          }
        ]
    }
