module Debate.Arguments.Inferences.UnhealthyCoconutOil exposing (..)

import Debate.Arguments.Types exposing (..)


argumentUnhealthyCoconutOil : Argument
argumentUnhealthyCoconutOil =
    { argumentTitle = "Argument For Atherogenic Coconut Oil"
    , propositionTitle = "There is not a reason to believe that coconut oil is any better for heart health than other saturated fat sources that increase LDL-C."
    , propositionReductio = ""
    , propositionSummary = "LDL causally associates with heart disease in a linear and proportional manner, and in all cases exposures that durably increase LDL over time produce likewise increases in heart disease risk. Coconut oil is one such exposure."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~1Qx~5~3Rx)),(Pc),(Qc)|=(~3Rc)"
    , argumentCertainty = 9
    , argumentImage = "coconutoil"
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "a given (x) increases LDL-C at a similar rate to other saturated fat sources"
          }
        , { definiendum = "Q"
          , definiens = "a given (x) has no other known qualities that counteract said increase in LDL-C"
          }
        , { definiendum = "R"
          , definiens = "there is a reason to believe that such an (x) is any better for heart health than other (x) that increase LDL-C"
          }
        , { definiendum = "x"
          , definiens = "a saturated fat source"
          }
        , { definiendum = "c"
          , definiens = "coconut oil"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If a given saturated fat source increases LDL-C at a similar rate to other saturated fat sources and and a given saturated fat source has no other known qualities that counteract said increase in LDL-C, then there is not a reason to believe that such a saturated fat source is any better for heart health than other saturated fat sources that increase LDL-C."
                  , notation = "∀x(Px∧Qx→¬Rx)"
                  }
                , { premise = "Coconut oil increases LDL-C at a similar rate to other saturated fat sources."
                  , notation = "Pc"
                  }
                , { premise = "Coconut oil has no other known qualities that counteract said increase in LDL-C."
                  , notation = "Qc"
                  }
                ]
          , conclusion = "Therefore, there is not a reason to believe that coconut oil is any better for heart health than other saturated fat sources that increase LDL-C."
          , conclusionNotation = "¬Rc"
          }
        ]
    }
